Advanced features
=================

This section introduces a number of features that you will useful in building
production-grade systems. In particular

* *scripts* - run arbitrary third-party Python packages with the same convenience as you run models and jobs
* *streams* - integrate with streaming sources or sinks, like Kafka, MQTT, web services or omega|ml datasets
* *integration* - use REST APIs to build applications from any data source
* *customizing* - extend omega|ml with custom plugins

.. toctree::
   :maxdepth: 2


   scripts/index
   streams/index
   integration/index
   customizing/index


